/*
# BUILD gl_platforms ['WGL']
# BUILD sources []
# BUILD api_version_check 0
# BUILD libs ['gdi32']
# BUILD include_dirs []
*/
#include "../config.h"

#include "WGL.EXT.extensions_string.0100.inc"
